@@ -24,9 +24,10 @@ LKrigSetupAwght <- function(object,...){
 }
 
 LKrigSetupAwght.default<- function( object,...){
-# object == LKinfo  
-   a.wght<- object$a.wght
+  a.wght<- object$a.wght
   nlevel<- object$nlevel
+  isotropic<- ifelse( length( a.wght)==1, TRUE, FALSE)
+  print( a.wght)
   if (!is.list(a.wght)) {
         # some checks on a.wght
         # coerce a.wght to list if it is passed as something
@@ -49,5 +50,8 @@ LKrigSetupAwght.default<- function( object,...){
 # default is to use the usual cholesky based normalization    
 # see LKRectangle for an example of something different.
      attr( a.wght, "fastNormalize") <- FALSE
+# tag helps to figure out if there is a single a.wght parameter or
+# more. 
+     attr( a.wght, "isotropic") <- isotropic
      return(a.wght)
  }
